@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.118';
+our $VERSION = '0.119';
 use 5.006;
 use strict;
 use warnings;
@@ -228,7 +228,7 @@ sub run {
 		return $j->_response($j->response);
 	}
 
-	return $j->_response($j->response, $j->content_type, $j->sid);
+	return $j->_response($j->response, $j->sid, $j->content_type);
 }
 
 sub to_app {
@@ -372,7 +372,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.118
+Version 0.119
 
 =cut
 
