@@ -86,6 +86,7 @@ sub build_terse {
 
 sub MODIFY_CODE_ATTRIBUTES {
 	my ($package, $coderef, @attributes, @disallowed) = @_;
+	no warnings qw(reserved);
 	my $name = svref_2object($coderef)->GV->NAME;
 	my %attr = PARSE_ATTRIBUTES($name, @attributes);
 	push @{ $Terse::Controller::dispatcher{$package}{$attr{req}} }, \%attr;
@@ -178,24 +179,30 @@ sub response_handle {
 	my ($content_type, $body) = $self->views->{$t->response_view || $self->response_view} 
 		? $t->view($t->response_view || $self->response_view)->render($t, $response_body) 
 		: ($ct, $response_body->serialize());
-	$body = undef if $response_body->error && $response_body->no_response;
 	$res = $t->_build_response($sid, $content_type, $response_body->status_code ||= $status ||= 200);
-	$res->body($body) if $body;
+	$res->body($body);
 	return $res->finalize;
 }
 
 sub dispatch {
 	my ($self, $req, $t, @params) = @_;
 	my $package = ref $self || $self;
-	my $dispatcher = $Terse::Controller::dispatcher{$package}{$req};
-	if (!$dispatcher) {
+	my $dispatch = $Terse::Controller::dispatcher{$package};
+	my @dispatcher = @{ $dispatch->{$req} || [] };
+	my @ISA = eval "\@${package}::ISA";
+	for (@ISA) {
+		$dispatch = $Terse::Controller::dispatcher{$_};
+		next unless $dispatch && $dispatch->{$req};
+		unshift @dispatcher, @{ $dispatch->{$req} };
+	}
+	if (!scalar @dispatcher) {
 		$t->logError('Invalid dispatch request', 400);
 		return;
 	}
-	my $dispatch;
+	$dispatch = undef;
 	my $path = $t->request->uri->path;
 	my $caps = scalar @{ $t->captured || [] };
-	DISPATCH: for my $candidate (reverse @{$dispatcher}) {
+	DISPATCH: for my $candidate (reverse @dispatcher) {
 		next DISPATCH unless ($candidate->{lc($t->request->method)} || $candidate->{any});
 		next DISPATCH unless (!$candidate->{captured} || $caps == $candidate->{captured});
 		if ($candidate->{params}) {
@@ -259,7 +266,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.118
+Version 0.119
 
 =cut
 
