@@ -18,7 +18,7 @@ sub hello :get {
 	$_[1]->response->hello = $_[1]->model('test')->something();
 }
 
-sub hello_get :get :path(app/(.*)/hello/world) {
+sub hello_get :get :path(app/(.*)/hello/world) :captured(1) {
 	$_[1]->response->hello = "world 2";
 }
 
