@@ -9,6 +9,7 @@ sub auth {
 
 sub hello_world {
 	my ($self, $t) = @_;
+	$t->logInfo('Hello this is a test');
 	$t->delayed_response(sub {
 		$t->response->hello = "world";
 		return $t->response;
@@ -22,14 +23,14 @@ sub web {
 		},
 		connect => sub {
 			my ($websocket) = @_;
-			$websocket->send('Hello ' x 1000);
+			$websocket->send(1);
 		},
 		recieve => sub {
 			my ($websocket) = @_;
-			$websocket->send('response');
+			$websocket->send($_[1]);
 		},
 		error => sub {
-			$t->logError('Kaput' . $_[1]);
+			$t->logError('Kaput' . $_[2]);
 		} 
 	);
 }	
